/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer;

import com.vividsolutions.jts.geom.Envelope;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.Point;
import com.vividsolutions.jts.geom.Polygon;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
public abstract class PolygonSupport implements Geometrical<Polygon> {

    private PropertyChangeSupport pcs = new PropertyChangeSupport(this);
    private com.vividsolutions.jts.geom.Polygon geometry;

    public PolygonSupport() {
    }

    public PolygonSupport(com.vividsolutions.jts.geom.Polygon geometry) {
        this.geometry = geometry;
    }

    @Override
    public com.vividsolutions.jts.geom.Polygon getGeometry() {
        return geometry;
    }

    @Override
    public Point getCentroid() {
        if (geometry != null) {
            return geometry.getCentroid();
        }
        return null;
    }

    @Override
    public Geometry getBoundingBox() {
        if (geometry != null) {
            return geometry.getEnvelope();
        }
        return null;
    }

    /**
     * Override this method if you need to optimize rendering for this object.
     * only return the part of the geometry that is within the provided envelope.
     * default implementation will always return the entire geometry
     * 
     * @param envelope
     * @return 
     */
    @Override
    public com.vividsolutions.jts.geom.Polygon getRenderObject(Envelope envelope) {
        return geometry;
    }

    @Override
    public String getTooltipText() {
        return "";
    }

    @Override
    public String getIconPath() {
        return null;
    }

    @Override
    public String getIconLabel() {
        return null;
    }

    @Override
    public void addPropertyChangeListener(PropertyChangeListener listener) {
        pcs.addPropertyChangeListener(listener);
    }

    @Override
    public void removePropertyChangeListener(PropertyChangeListener listener) {
        pcs.removePropertyChangeListener(listener);
    }
}
